@@ -7,7 +7,7 @@
     im3,im2,im1,im,mm3dc,mm2dc,mm1dc,mmdc,im3dc,im2dc,im1dc,imdc,date,datedc,zi,&
     c,cdc,nt0,nt1,nt1dc,nsujet,nva,nva1,nva2,ndate,ndatedc,nst, &
     effet,stra,ve,vedc,pe,ng,g,nig,indic_ALPHA,ALPHA,theta,nstRec,k0T, &
-    auxig,aux1,aux2,res1,res3,kkapa,resnonpen
+    auxig,aux1,aux2,res1,res3,kkapa,resnonpen,wtsvec
     use residusM
     !use comongroup,only:the1
     use comongroup,only:vet,vet2,the2
@@ -291,10 +291,10 @@
 !     developpement de taylor d ordre 3
 !*************************************************************************
 !                   write(*,*)'************** TAYLOR *************'                   
-                res= res + res2(k) &
+                res= res + wtsvec(k)*(res2(k) &
                 + res2dc(k)  &
                 - gammaJ(1./theta)-dlog(theta)/theta  &
-                + dlog(integrale3(k))
+                + dlog(integrale3(k))) ! IJ: weighted each individual likelihood contribution
             endif
             if ((res.ne.res).or.(abs(res).ge. 1.d30)) then
 !                 print*,"here",k,res2(k),res2dc(k),gammaJ(1./theta),dlog(theta),dlog(integrale3(k))
